
# THIS FILE IS GENERATED FROM SETUP.PY
short_version = '0.1.0'
version = '0.1.0'
full_version = '0.1.0'
git_revision = '220ee54c8e8888359d7a6ce0eda53a9b7b972f49'
release = True

if not release:
    version = full_version
